/* $Id: cgencompl.c,v 1.3 1997/03/28 14:07:36 queinnec Exp $ */

#include "config.h"

#include <stdio.h>

#if HAVE_FCNTL_H
#include <fcntl.h>
#endif

#if HAVE_STRING_H
#include <string.h>
#else
int strcmp (const char *, const char *);
#endif

#include <moviedb.h>
#include "array.h"
#include "translation.h"
#include "readname.h"
#include "constants.h"
#include "imoviedb.h"

static const char *rcsid = "$Id";

void dump_names()
{
    const char *keyfile = NAMEKEY;
    const char *complfile = NAMECOMPL;
    Array *array;
    int fd;
    
    fd = open (complfile, O_WRONLY|O_CREAT|O_TRUNC, 0644);
    if (fd == -1) {
        fprintf (stderr, "cgencompl: can't open %s: ", complfile);
        perror ("");
        exit (1);
    }
    
    array = array_create (TRUE, translations_iso2ascii_lc);
    if (array == NULL)
      exit (1);
    if (readname_namekeyfile (array, keyfile) == ERROR) {
        fprintf (stderr, "%s not loaded\n", keyfile);
        exit (1);
    }
    array_stat (array);
    
    printf ("Saving as %s\n", complfile);
    if (array_save (array, fd) == -1) {
        fprintf (stderr, "%s not saved\n", complfile);
        unlink (complfile);
    }
    if (close (fd) == -1) {
        fprintf (stderr, "cgencompl: can't close %s: ", complfile);
        perror ("");
        unlink (complfile);
    }
    array_destroy (array);
}

void dump_titles()
{
    const char *keyfile = TITLEKEY;
    const char *complfile = TITLECOMPL;
    Array *array;
    int fd;

    fd = open (complfile, O_WRONLY|O_CREAT|O_TRUNC, 0644);
    if (fd == -1) {
        fprintf (stderr, "cgencompl: can't open %s: ", complfile);
        perror ("");
        exit (1);
    }
    
    array = array_create (TRUE, translations_iso2ascii_lc);
    if (array == NULL)
      exit (1);
    if (readname_titlekeyfile (array, keyfile, TRUE, 0, 0) == ERROR) {
        fprintf (stderr, "%s not loaded\n", keyfile);
        exit (1);
    }
    array_stat (array);
    
    printf ("Saving as %s\n", complfile);
    if (array_save (array, fd) == -1) {
        fprintf (stderr, "%s not saved\n", complfile);
        unlink (complfile);
    }
    if (close (fd) == -1) {
        fprintf (stderr, "cgencompl: can't close %s: ", complfile);
        perror ("");
        unlink (complfile);
    }
    array_destroy (array);
}

static char *usage = "cgencompl [-names|-titles|-all]";

int main (int argc, char **argv)
{
    if (argc != 2) {
        fprintf (stderr, "%s\n", usage);
        exit (1);
    }
    if (strcmp (argv[1], "-names") == 0) {
        dump_names();
    } else if (strcmp (argv[1], "-titles") == 0) {
        dump_titles();
    } else if (strcmp (argv[1], "-all") == 0) {
        dump_titles();
        dump_names();
    } else {
        fprintf (stderr, "%s\n", usage);
        exit (1);
    }
    return 0;
}
