#include "config.h"

#include <stdio.h>

#if HAVE_STRING_H
#include <string.h>
#else
int strcmp (const char *, const char *);
int strncmp (const char *, const char *, int);
int strlen (const char *);
#endif

#include <assert.h>
#include <moviedb.h>
#include "array.h"
#include "readname.h"
#include "translation.h"
#include "constants.h"
#include "command.h"
#include "exec.h"
#include "imoviedb.h"

static const char *rcsid = "$Id: clist.c,v 1.22 1997/03/28 14:08:18 queinnec Exp $";

struct option {
    const char *optname;
    const char *dbsstem;
};

static struct option options[] = {
    { "-acr", ACRSTEM },
    { "-acs", ACSSTEM },
    { "-dir",  DIRSTEM },
    { "-write",  WRITESTEM },
    { "-comp",  COMPSTEM },
    { "-cine", CINESTEM },
    { "-edit", EDITSTEM },
    { "-prodes", PDESSTEM },
    { "-costdes", CDESSTEM },
    { "-prdcr", PRDCRSTEM },
    { NULL,  NULL }
};
    
static Array *init_array (int argc, char **argv)
{
    Array *themem = NULL;
    int onedbsloaded = FALSE;
    const struct option *opt;
    const char *progname = argv[0];
    for (argv++, argc--; argc != 0; argv++, argc--) {
        for (opt = &(options[0]); opt->optname != NULL; opt++) {
            if (strcmp (*argv, opt->optname) == 0) {
                if (themem == NULL) {
                    themem = array_create (TRUE, translations_iso2ascii_lc);
                    if (themem == NULL)
                      exit (1);
                }
                if (readname_dbs (themem, opt->dbsstem) == ERROR) {
                    fprintf (stderr, "%s not loaded\n", *argv);
                    exit (1);
                }
                onedbsloaded = TRUE;
                break;
            }
        }
        if (opt->optname == NULL) {
            if (strncmp (*argv, "-o", 2) == 0) {
                char *command;
                if (strlen (*argv) == 2) {
                    /* first form: clist -o toto */
                    argv++, argc--;
                    if (argc == 0) {
                        fprintf (stderr, "Missing argument for -o\n");
                        exit (1);
                    }
                    command = *argv;
                } else {
                    /* second form: clist -ototo */
                    command = *argv + 2;
                }
                if ((command[0] == '!') || (command[0] == '|'))
                  set_default_output (REDIR_CMDE, command+1);
                else
                  set_default_output (REDIR_FILE, command);
            } else {
                /* Not an option */
                fprintf (stderr,
                         "%s [-acr -acs -dir -write -comp -cine -edit -prodes -costdes -prdcr]*\n",
                         progname);
                fprintf (stderr, "     [-o file]   (|command or !command to pipe into a command)\n");
                fprintf (stderr, " no arguments == load all names\n");
                exit (1);
            }
        }
    }
    if (! onedbsloaded) {
        assert (themem == NULL);
        themem = readname_loadname (NAMECOMPL, NAMEKEY);
    } else {
        unsigned int nbinserted;
        array_endinsertion (themem);
        nbinserted = array_nb_of_words (themem);
        fprintf (stderr, "%u names inserted.\n", nbinserted);
    }
    return (themem);
}

int main (int argc, char **argv)
{
    Array *array;
    int cltrace = FALSE;
    array = init_array (argc, argv);
    if (strlen (argv[0]) >= strlen ("cltrace")) {
        cltrace = (strcmp (argv[0] + strlen (argv[0]) - strlen ("cltrace"),
                          "cltrace") == 0);
    }
    init_commands (array, NULL);
    name_loop ((cltrace ? command_ltrace : command_list),
               "quit to quit", "quit");
    exit (0);
    return (0);
}

