# Local additions to Autoconf macros.
# $Id: aclocal.m4,v 1.2 1996/11/01 14:47:56 queinnec Exp $

## ------------------------------- ##
## Check for function prototypes.  ##
## ------------------------------- ##
AC_DEFUN(fp_C_PROTOTYPES,
[AC_REQUIRE([fp_PROG_CC_STDC])
AC_MSG_CHECKING([for function prototypes])
if test "$ac_cv_prog_cc_stdc" != no; then
  AC_MSG_RESULT(yes)
else
  AC_MSG_RESULT(no)
  AC_MSG_ERROR([**** No support for K&R C. Sorry...])
fi
])


# @defmac AC_PROG_CC_STDC
# @maindex PROG_CC_STDC
# @ovindex CC
# If the C compiler in not in ANSI C mode by default, try to add an option
# to output variable @code{CC} to make it so.  This macro tries various
# options that select ANSI C on some system or another.  It considers the
# compiler to be in ANSI C mode if it defines @code{__STDC__} to 1 and
# handles function prototypes correctly.
# 
# If you use this macro, you should check after calling it whether the C
# compiler has been set to accept ANSI C; if not, the shell variable
# @code{ac_cv_prog_cc_stdc} is set to @samp{no}.  If you wrote your source
# code in ANSI C, you can make an un-ANSIfied copy of it by using the
# program @code{ansi2knr}, which comes with Ghostscript.
#
# Stolen from recode-3.4, written by Francois Pinard <pinard@iro.umontreal.ca>
# @end defmac

AC_DEFUN(fp_PROG_CC_STDC,
[AC_MSG_CHECKING(for ${CC-cc} option to accept ANSI C)
AC_CACHE_VAL(ac_cv_prog_cc_stdc,
[ac_cv_prog_cc_stdc=no
ac_save_CFLAGS="$CFLAGS"
# Don't try gcc -ansi; that turns off useful extensions and
# breaks some systems' header files.
# AIX			-qlanglvl=ansi
# Ultrix and OSF/1	-std1
# HP-UX			-Aa -D_HPUX_SOURCE
# SVR4			-Xc
for ac_arg in "" -qlanglvl=ansi -std1 "-Aa -D_HPUX_SOURCE" -Xc
do
  CFLAGS="$ac_save_CFLAGS $ac_arg"
  AC_TRY_COMPILE(
[#if !defined(__STDC__) || __STDC__ != 1
choke me
#endif	
], [int test (int i, double x);
struct s1 {int (*f) (int a);};
struct s2 {int (*f) (double a);};],
[ac_cv_prog_cc_stdc="$ac_arg"; break])
done
CFLAGS="$ac_save_CFLAGS"
])
AC_MSG_RESULT($ac_cv_prog_cc_stdc)
case "x$ac_cv_prog_cc_stdc" in
  x|xno) ;;
  *) CC="$CC $ac_cv_prog_cc_stdc" ;;
esac
])


# ------------------------------- 
# Option to use zlib
# (partially stolen from Francois Pinard <pinard@iro.umontreal.ca>)
AC_DEFUN(pq_WITH_ZLIB,
[AC_MSG_CHECKING(wheter zlibrary is wanted)
AC_ARG_WITH(zlib,
[  --with-zlib			use zlib compression library.],
[pq_with_zlib="$withval"
AC_MSG_RESULT("$withval")],
[pq_with_zlib=no
AC_MSG_RESULT(no)])])


# ------------------------------- 
# Test for half-working mmap.
# HP9000 has mmap, but it's not "working", based on AC_FUNC_MMAP test.
# This is mainly because there is no valloc(3), so the test for mmap uses
# malloc, which gives a block which is not page-aligned, and so mmap fails.
# imoviedb only need mmap(0,...), so a lighter test is used.
AC_DEFUN(pq_FUNC_MMAP,
[if test $ac_cv_func_mmap = yes; then
  pq_cv_func_mmap=yes
else
AC_CACHE_CHECK(for half-working mmap, pq_cv_func_mmap,
[AC_TRY_RUN([
#include <sys/types.h>
#include <fcntl.h>
#include <sys/mman.h>

#define TABSIZE 10000
int main()
{
  int fd, i;
  int *buf;
  int tab[TABSIZE];
  for (i = 0; i < TABSIZE; i++)
    tab[i] = i;
  fd = open ("conftestmmap2", O_CREAT | O_TRUNC | O_WRONLY, 0666);
  write (fd, tab, TABSIZE * sizeof(int));
  close (fd);
  fd = open ("conftestmmap2", O_RDONLY);
  buf = (int *) mmap (0, TABSIZE * sizeof(int), PROT_READ, MAP_PRIVATE, fd, 0);
  for (i = 0; i < TABSIZE; i++, buf++)
    if (*buf != i)
      exit (1);
  exit (0);
}
], pq_cv_func_mmap=yes, pq_cv_func_mmap=no, pq_cv_func_mmap=no)])
if test $pq_cv_func_mmap = yes; then
  AC_DEFINE(HAVE_MMAP)
fi
fi])

# ------------------------------- 
# Where is moviedb installed ?
AC_DEFUN(pq_WITH_MOVIEDB,
[AC_MSG_CHECKING(where is moviedb)
AC_ARG_WITH(moviedb,
[  --with-moviedb=dirname	where is moviedb installed ?],
[MOVIEDBDIR="$withval"],
[if test "x$prefix" = "xNONE"; then
   MOVIEDBDIR=$ac_default_prefix
else
   MOVIEDBDIR=$prefix
fi])
AC_MSG_RESULT("$MOVIEDBDIR")
if test ! -d $MOVIEDBDIR/dbs; then
  AC_MSG_WARN([**** dbs directory not found there! ****])
fi
AC_SUBST(MOVIEDBDIR)
AC_DEFINE_UNQUOTED(DBDIR, "$MOVIEDBDIR/dbs/")])

# Where are moviedb sources ?
AC_DEFUN(pq_WITH_MOVIEDBSRC,
[AC_MSG_CHECKING(where are moviedb sources)
AC_ARG_WITH(moviedbsrc,
[  --with-moviedbsrc=dirname	where are moviedb sources ?],
[MOVIEDBSRCDIR="$withval"],
[MOVIEDBSRCDIR="${MOVIEDBDIR}/src"])
AC_MSG_RESULT("$MOVIEDBSRCDIR")
if test ! -f $MOVIEDBSRCDIR/dbutils.c; then
  AC_MSG_WARN([**** dbutils.c not found there! ****])
else
if test ! -f $MOVIEDBSRCDIR/dbutils.o; then
  AC_MSG_WARN([**** You must first compile moviedb. ****])
fi
fi
AC_SUBST(MOVIEDBSRCDIR)])

# -------------------------------
# Set dbsdir, where the completion files will be written.
AC_DEFUN(pq_COMPL_DIR,
[if test "x$prefix" = "xNONE"; then
   dbsdir="${ac_default_prefix}/dbs"
else
   dbsdir="${prefix}/dbs"
fi
AC_SUBST(dbsdir)
AC_DEFINE_UNQUOTED(COMPLDIR, "$dbsdir/")])


# -------------------------------
# configuration synthesis
AC_DEFUN(pq_MSG_CONFIG,
[cat 1>&AC_FD_MSG <<EOF

Configuration:
  Using zlibrary...	 $pq_with_zlib
  Using mmap...		 $pq_cv_func_mmap
  Installing in...	 $prefix
  moviedb databases...	 $MOVIEDBDIR/dbs
  moviedb sources...	 $MOVIEDBSRCDIR
  imoviedb completion... $dbsdir
EOF
])
