#include "config.h"

#include <stdio.h>

#if HAVE_STRING_H
#include <string.h>
#else
int strcmp (const char *, const char *);
int strncmp (const char *, const char *, int);
int strlen (const char *);
#endif

#if HAVE_STDLIB_H
#include <stdlib.h>
#endif

#include <moviedb.h>
#include "array.h"
#include "readname.h"
#include "constants.h"
#include "command.h"
#include "exec.h"
#include "imoviedb.h"

static const char *rcsid = "$Id: ctitle.c,v 1.18 1996/10/26 16:09:45 queinnec Exp $";

static int keepyear = FALSE;
static unsigned int fromyear = 0;
static unsigned int toyear = 0;

static void handle_args (int argc, char **argv)
{
    const char *progname = argv[0];
    for (argv++, argc--; argc != 0; argv++, argc--) {
        if (strncmp (*argv, "-o", 2) == 0) {
            char *command;
            if (strlen (*argv) == 2) {
                /* first form: -o toto */
                argv++, argc--;
                if (argc == 0) {
                    fprintf (stderr, "Missing argument for -o\n");
                    exit (1);
                }
                command = *argv;
            } else {
                /* second form: -ototo */
                command = *argv + 2;
            }
            if ((command[0] == '!') || (command[0] == '|'))
              set_default_output (REDIR_CMDE, command+1);
            else
              set_default_output (REDIR_FILE, command);
        } else if (strcmp (*argv, "-keepyear") == 0) {
            keepyear = TRUE;
        } else if (strcmp (*argv, "-from") == 0) {
            argv++, argc--;
            if (argc == 0) {
                fprintf (stderr, "Missing argument for -from\n");
                exit (1);
            }
            fromyear = atoi (*argv);
        } else if (strcmp (*argv, "-to") == 0) {
            argv++, argc--;
            if (argc == 0) {
                fprintf (stderr, "Missing argument for -to\n");
                exit (1);
            }
            toyear = atoi (*argv);
        } else {
            fprintf (stderr,
                     "%s [-keepyear] [-o file] [-from year] [-to year]\n",
                     progname);
            fprintf (stderr,
                     "   (|command or !command to pipe into a command)\n");
            fprintf (stderr,
                     "   (from year is inclusive, to year is exclusive)\n");
            exit (1);
        }
    }
}

int main (int argc, char **argv)
{
    Array *array;
    int clistall = FALSE;
    handle_args (argc, argv);
    array = readname_loadtitle (TITLECOMPL, TITLEKEY,
                                !keepyear, fromyear, toyear);
    if (strlen (argv[0]) >= strlen ("clistall")) {
        clistall = (strcmp (argv[0] + strlen (argv[0]) - strlen ("clistall"),
                          "clistall") == 0);
    }
    init_commands (NULL, array);
    name_loop ((clistall ? command_listall : command_title),
               "quit to quit", "quit");
    exit (0);
    return (0);
}

