
#include "config.h"
#include "translation.h"

static const char *rcsid = "$Id: translation.c,v 1.2 1997/03/29 14:35:33 queinnec Exp $";


int tr_strcmp (const unsigned char *s1, const unsigned char *s2,
              unsigned char table[])
{
    const unsigned char *p, *q;
    for (p = s1, q = s2;
         *p && *q && (table[*p] == table[*q]);
         p++, q++) /* empty */;
    return table[*p] - table[*q];
}

int tr_strncmp (const unsigned char *s1, const unsigned char *s2,
               unsigned int n, unsigned char table[])
{
    const unsigned char *p, *q;
    for (p = s1, q = s2;
         (n != 0) && *p && *q && (table[*p] == table[*q]);
         n--, p++, q++) /* empty */;
    if (n == 0)
      return 0;
    else
      return table[*p] - table[*q];
}





/* "Translation" iso 8859/1 -> ascii  */

unsigned char translations_iso2ascii[256] = {
    000, 001, 002, 003, 004, 005, 006, 007, 
    010, 011, 012, 013, 014, 015, 016, 017, 
    020, 021, 022, 023, 024, 025, 026, 027, 
    030, 031, 032, 033, 034, 035, 036, 037,
    
    ' ',  '!', '"', '#', '$', '%', '&', '\'', 
    '(', ')', '*', '+', ',', '-', '.', '/', 
    '0', '1',  '2', '3', '4', '5', '6', '7', 
    '8', '9', ':', ';', '<', '=', '>', '?', 
    '@', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 
    'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 
    'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 
    'X', 'Y', 'Z', '[', '\\', ']', '^', '_', 
    '`', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 
    'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 
    'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 
    'x', 'y', 'z', '{', '|',  '}', '~', 0177,

    0200, 0201, 0202, 0203, 0204, 0205, 0206, 0207,
    0210, 0211, 0212, 0213, 0214, 0215, 0216, 0217, 
    0220, 0221, 0222, 0223, 0224, 0225, 0226, 0227, 
    0230, 0231, 0232, 0233, 0234, 0235, 0236, 0237,

    0240, 0241, 0242, 0243, 0244, 0245, 0246, 0247, 
    0250, 0251, 0252, 0253, 0254, 0255, 0256, 0257, 
    0260, 0261, 0262, 0263, 0264, 0265, 0266, 0267, 
    0270, 0271, 0272, 0273, 0274, 0275, 0276, 0277,

    'A', 'A', 'A', 'A', 'A', 'A', 0306, 'C',  /* A` A' A^ A~ A" Ao AE C, */
    'E', 'E', 'E', 'E', 'I', 'I', 'I', 'I',   /* E` E' E^ E" I` I' I^ I" */
    0320, 'N', 'O', 'O', 'O', 'O', 'O', '*',  /* D? N~ O` O' O^ O~ O" x  */
    'O', 'U', 'U', 'U', 'U', 'Y', 0336, 0337, /* O/ U` U' U^ U" Y' ?  SS */
    'a', 'a', 'a', 'a', 'a', 'a', 0346, 'c',  /* a` a' a^ a~ a" ao ae c, */
    'e', 'e', 'e', 'e', 'i', 'i', 'i', 'i',   /* e` e' e^ e" i` i' i^ i" */
    0360, 'n', 'o', 'o', 'o', 'o', 'o', '/',  /* d? n~ o` o' o^ o~ o" /  */
    'o', 'u', 'u', 'u', 'u', 'y', 0376, 0377  /* o/ u` u' u^ u" y' ?  ss */
};

/* Translation iso 8859 -> ascii lowercase */
unsigned char translations_iso2ascii_lc[256] = {
    000, 001, 002, 003, 004, 005, 006, 007, 
    010, 011, 012, 013, 014, 015, 016, 017, 
    020, 021, 022, 023, 024, 025, 026, 027, 
    030, 031, 032, 033, 034, 035, 036, 037,
    
    ' ',  '!', '"', '#', '$', '%', '&', '\'', 
    '(', ')', '*', '+', ',', '-', '.', '/', 
    '0', '1',  '2', '3', '4', '5', '6', '7', 
    '8', '9', ':', ';', '<', '=', '>', '?', 
    '@', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 
    'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 
    'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 
    'x', 'y', 'z', '[', '\\', ']', '^', '_', 
    '`', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 
    'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 
    'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 
    'x', 'y', 'z', '{', '|',  '}', '~', 0177,

    0200, 0201, 0202, 0203, 0204, 0205, 0206, 0207, 
    0210, 0211, 0212, 0213, 0214, 0215, 0216, 0217, 
    0220, 0221, 0222, 0223, 0224, 0225, 0226, 0227, 
    0230, 0231, 0232, 0233, 0234, 0235, 0236, 0237,

    0240, 0241, 0242, 0243, 0244, 0245, 0246, 0247, 
    0250, 0251, 0252, 0253, 0254, 0255, 0256, 0257, 
    0260, 0261, 0262, 0263, 0264, 0265, 0266, 0267, 
    0270, 0271, 0272, 0273, 0274, 0275, 0276, 0277,

    'a', 'a', 'a', 'a', 'a', 'a', 0346, 'c',  /* A` A' A^ A~ A" Ao AE C, */
    'e', 'e', 'e', 'e', 'i', 'i', 'i', 'i',   /* E` E' E^ E" I` I' I^ I" */
    0360, 'n', 'o', 'o', 'o', 'o', 'o', '*',  /* D? N~ O` O' O^ O~ O" x  */
    'o', 'u', 'u', 'u', 'u', 'y', 0376, 0377, /* O/ U` U' U^ U" Y' ?  SS */
    'a', 'a', 'a', 'a', 'a', 'a', 0346, 'c',  /* a` a' a^ a~ a" ao ae c, */
    'e', 'e', 'e', 'e', 'i', 'i', 'i', 'i',   /* e` e' e^ e" i` i' i^ i" */
    0360, 'n', 'o', 'o', 'o', 'o', 'o', '/',  /* d? n~ o` o' o^ o~ o" /  */
    'o', 'u', 'u', 'u', 'u', 'y', 0376, 0377  /* o/ u` u' u^ u" y' ?  ss */
};


#if 0

unsigned char translations_ascii2ascii_lc[256] = {
    000, 001, 002, 003, 004, 005, 006, 007, 
    010, 011, 012, 013, 014, 015, 016, 017, 
    020, 021, 022, 023, 024, 025, 026, 027, 
    030, 031, 032, 033, 034, 035, 036, 037,
    
    ' ',  '!', '"', '#', '$', '%', '&', '\'', 
    '(', ')', '*', '+', ',', '-', '.', '/', 
    '0', '1',  '2', '3', '4', '5', '6', '7', 
    '8', '9', ':', ';', '<', '=', '>', '?', 
    '@', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 
    'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 
    'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 
    'x', 'y', 'z', '[', '\\', ']', '^', '_', 
    '`', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 
    'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 
    'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 
    'x', 'y', 'z', '{', '|',  '}', '~', 0177,

    0200, 0201, 0202, 0203, 0204, 0205, 0206, 0207, 
    0210, 0211, 0212, 0213, 0214, 0215, 0216, 0217, 
    0220, 0221, 0222, 0223, 0224, 0225, 0226, 0227, 
    0230, 0231, 0232, 0233, 0234, 0235, 0236, 0237,

    0240, 0241, 0242, 0243, 0244, 0245, 0246, 0247, 
    0250, 0251, 0252, 0253, 0254, 0255, 0256, 0257, 
    0260, 0261, 0262, 0263, 0264, 0265, 0266, 0267, 
    0270, 0271, 0272, 0273, 0274, 0275, 0276, 0277,

    0300, 0301, 0302, 0303, 0304, 0305, 0306, 0307, 
    0310, 0311, 0312, 0313, 0314, 0315, 0316, 0317, 
    0320, 0321, 0322, 0323, 0324, 0325, 0326, 0327, 
    0330, 0331, 0332, 0333, 0334, 0335, 0336, 0337,

    0340, 0341, 0342, 0343, 0344, 0345, 0346, 0347, 
    0350, 0351, 0352, 0353, 0354, 0355, 0356, 0357, 
    0360, 0361, 0362, 0363, 0364, 0365, 0366, 0367, 
    0370, 0371, 0372, 0373, 0374, 0375, 0376, 0377,
};

/* Stupid, isn't it ? */
unsigned char translations_do_nothing[256] = {
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18,
    19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
    35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50,
    51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66,
    67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82,
    83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98,
    99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111,
    112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124,
    125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137,
    138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150,
    151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163,
    164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176,
    177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189,
    190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202,
    203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215,
    216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228,
    229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241,
    242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254,
    255, 256
};    
#endif
